bayespy.inference.vmp.nodes.stochastic.Stochastic.add_plate_axis
================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.stochastic

.. automethod:: Stochastic.add_plate_axis